gRPC Typing Stubs for Python
============================

This is a PEP-561-compliant stub-only package which provides type information of
`gRPC <https://grpc.io>`_.

Install using pip::

    pip install grpc-stubs


Tests (courtesy of `pytest-mypy-plugins <https://github.com/typeddjango/pytest-mypy-plugins>`_)::

    pip install -r dev-requirements.txt
    ./tools.sh test


Other Very Useful Typed Python Stuff
------------------------------------

- https://github.com/TypedDjango
- https://github.com/typeddjango/pytest-mypy-plugins
- https://github.com/typeddjango/awesome-python-stubs

